@@ -833,7 +833,7 @@ sync_done:
 	}
 
 	if (td->trim_entries)
-		printf("trim entries %ld\n", td->trim_entries);
+		log_err("fio: %d trim entries leaked?\n", td->trim_entries);
 
 	if (td->o.fill_device && td->error == ENOSPC) {
 		td->error = 0;
@@ -1560,7 +1560,7 @@ static void run_threads(void)
 						nr_thread > 1 ? "s" : "");
 		if (nr_process) {
 			if (nr_thread)
-				printf(" and ");
+				log_info(" and ");
 			log_info("%d process%s", nr_process,
 						nr_process > 1 ? "es" : "");
 		}
