@@ -32,6 +32,7 @@ static int server_fd = -1;
 static char *fio_server_arg;
 static char *bind_sock;
 static struct sockaddr_in saddr_in;
+static int first_cmd_check;
 
 static const char *fio_server_ops[FIO_NET_CMD_NR] = {
 	"",
@@ -48,6 +49,7 @@ static const char *fio_server_ops[FIO_NET_CMD_NR] = {
 	"START",
 	"STOP",
 	"DISK_UTIL",
+	"RUN",
 };
 
 const char *fio_server_op(unsigned int op)
@@ -181,8 +183,12 @@ struct fio_net_cmd *fio_net_recv_cmd(int sk)
 
 		if (first)
 			memcpy(cmdret, &cmd, sizeof(cmd));
-		else
-			assert(cmdret->opcode == cmd.opcode);
+		else if (cmdret->opcode != cmd.opcode) {
+			log_err("fio: fragment opcode mismatch (%d != %d)\n",
+					cmdret->opcode, cmd.opcode);
+			ret = 1;
+			break;
+		}
 
 		if (!cmd.pdu_len)
 			break;
@@ -326,6 +332,8 @@ static int fio_server_send_quit_cmd(void)
 static int handle_job_cmd(struct fio_net_cmd *cmd)
 {
 	char *buf = (char *) cmd->payload;
+	struct cmd_start_pdu spdu;
+	struct cmd_end_pdu epdu;
 	int ret;
 
 	if (parse_jobs_ini(buf, 1, 0)) {
@@ -333,9 +341,14 @@ static int handle_job_cmd(struct fio_net_cmd *cmd)
 		return -1;
 	}
 
-	fio_net_send_simple_cmd(server_fd, FIO_NET_CMD_START, 0, NULL);
+	spdu.jobs = cpu_to_le32(thread_number);
+	fio_net_send_cmd(server_fd, FIO_NET_CMD_START, &spdu, sizeof(spdu), 0);
 
 	ret = exec_run();
+
+	epdu.error = ret;
+	fio_net_send_cmd(server_fd, FIO_NET_CMD_STOP, &epdu, sizeof(epdu), 0);
+
 	fio_server_send_quit_cmd();
 	reset_fio_state();
 	return ret;
@@ -539,6 +552,8 @@ static int handle_connection(int sk, int block)
 
 void fio_server_idle_loop(void)
 {
+	if (!first_cmd_check)
+		fio_net_send_simple_cmd(server_fd, FIO_NET_CMD_RUN, 0, NULL);
 	if (server_fd != -1)
 		handle_connection(server_fd, 0);
 }
